.. _about:

=====
About
=====


Citation
--------

.. admonition:: Reference

   Gorgolewski, Krzysztof J.;   Esteban, Oscar;   Ellis, David Gage;   Notter,
   Michael Philipp;   Ziegler, Erik;   Johnson, Hans;   Hamalainen, Carlo;
   Yvernault, Benjamin; Burns, Christopher;   Manhães-Savio, Alexandre;
   Jarecka, Dorota;  Markiewicz, Christopher J.;   Salo, Taylor;   Clark, Daniel;
   Waskom, Michael; Wong, Jason; Modat, Marc;   Dewey, Blake E; Clark, Michael G.;
   Dayan, Michael; Loney, Fred; Madison, Cindee;   Gramfort, Alexandre;
   Keshavan, Anisha; Berleant, Shoshana; Pinsard, Basile; Goncalves, Mathias;
   Clark, Dav;   Cipollini, Ben;   Varoquaux, Gael;  Wassermann , Demian;
   Rokem, Ariel;   Halchenko, Yaroslav O.; Forbes, Jessica; Moloney, Brendan;
   Malone, Ian B.;  Hanke, Michael; Mordom, David; Buchanan, Colin;
   PAULI, WOLFGANG M.;   Huntenburg, Julia M.;   Horea, Christian; Schwartz,
   Yannick; Tungaraza, Rosalia;   Iqbal, Shariq; Kleesiek, Jens; Sikka, Sharad;
   Frohlich, Caroline; Kent, James; Perez-Guevara, Martin; Watanabe, Aimi; Welch,
   David; Cumba, Chad; Ginsburg, Daniel;   Eshaghi, Arman;   Kastman, Erik;
   Bougacha, Salma; Blair, Ross;   Acland, Benjamin;   Gillman, Ashley;   Schaefer,
   Alexander;   Nichols, B. Nolan; Giavasis, Steven; Erickson, Drew; Correa,
   Carlos; Ghayoor, Ali; Küttner, René; Haselgrove, Christian; Zhou, Dale;
   Craddock, R. Cameron; Haehn, Daniel; Lampe, Leonie; Millman, Jarrod; Lai, Jeff;
   Renfro, Mandy; Liu, Siqi;   Stadler, Jörg;   Glatard, Tristan;   Kahn, Ari E.;
   Kong, Xiang-Zhen;   Triplett, William; Park, Anne; McDermottroe, Conor;
   Hallquist, Michael; Poldrack, Russell; Perkins, L. Nathan; Noel, Maxime;
   Gerhard, Stephan; Salvatore, John; Mertz, Fred;   Broderick, William;
   Inati, Souheil; Hinds, Oliver; Brett, Matthew;   Durnez, Joke; Tambini,
   Arielle; Rothmei, Simon;   Andberg, Sami Kristian;  Cooper, Gavin; Marina,
   Ana; Mattfeld, Aaron; Urchs, Sebastian; Sharp, Paul; Matsubara, K;   Geisler,
   Daniel; Cheung, Brian;  Floren, Andrew; Nickson, Thomas;   Pannetier, Nicolas;
   Weinstein, Alejandro; Dubois, Mathieu; Arias, Jaime; Tarbert, Claire; Schlamp,
   Kai;   Jordan, Kesshi; Liem, Franz; Saase, Victor; Harms, Robbert; Khanuja,
   Ranjeet; Podranski, Kornelius; Flandin, Guillaume;   Papadopoulos Orfanos,
   Dimitri; Schwabacher, Isaac;   McNamee, Daniel; Falkiewicz, Marcel;
   Pellman, John;   Linkersdörfer, Janosch; Varada, Jan;   Pérez-García, Fernando;
   Davison, Andrew; Shachnev, Dmitry;  Ghosh, Satrajit (2017). Nipype:
   a flexible, lightweight and extensible neuroimaging data processing framework in Python.
   0.13.0 Zenodo. `10.5281/zenodo.581704 <https://doi.org/10.5281/zenodo.581704>`_

::

     @misc{gorgolewski_krzysztof_j_2017_581704,
	  author   = {Gorgolewski, Krzysztof J. and
                  Esteban, Oscar and
                  Ellis, David Gage and
                  Notter, Michael Philipp and
                  Ziegler, Erik and
                  Johnson, Hans and
                  Hamalainen, Carlo and
                  Yvernault, Benjamin and
                  Burns, Christopher and
                  Manhães-Savio, Alexandre and
                  Jarecka, Dorota and
                  Markiewicz, Christopher J. and
                  Salo, Taylor and
                  Clark, Daniel and
                  Waskom, Michael and
                  Wong, Jason and
                  Modat, Marc and
                  Dewey, Blake E and
                  Clark, Michael G. and
                  Dayan, Michael and
                  Loney, Fred and
                  Madison, Cindee and
                  Gramfort, Alexandre and
                  Keshavan, Anisha and
                  Berleant, Shoshana and
                  Pinsard, Basile and
                  Goncalves, Mathias and
                  Clark, Dav and
                  Cipollini, Ben and
                  Varoquaux, Gael and
                  Wassermann , Demian and
                  Rokem, Ariel and
                  Halchenko, Yaroslav O. and
                  Forbes, Jessica and
                  Moloney, Brendan and
                  Malone, Ian B. and
                  Hanke, Michael and
                  Mordom, David and
                  Buchanan, Colin and
                  PAULI, WOLFGANG M. and
                  Huntenburg, Julia M. and
                  Horea, Christian and
                  Schwartz, Yannick and
                  Tungaraza, Rosalia and
                  Iqbal, Shariq and
                  Kleesiek, Jens and
                  Sikka, Sharad and
                  Frohlich, Caroline and
                  Kent, James and
                  Perez-Guevara, Martin and
                  Watanabe, Aimi and
                  Welch, David and
                  Cumba, Chad and
                  Ginsburg, Daniel and
                  Eshaghi, Arman and
                  Kastman, Erik and
                  Bougacha, Salma and
                  Blair, Ross and
                  Acland, Benjamin and
                  Gillman, Ashley and
                  Schaefer, Alexander and
                  Nichols, B. Nolan and
                  Giavasis, Steven and
                  Erickson, Drew and
                  Correa, Carlos and
                  Ghayoor, Ali and
                  Küttner, René and
                  Haselgrove, Christian and
                  Zhou, Dale and
                  Craddock, R. Cameron and
                  Haehn, Daniel and
                  Lampe, Leonie and
                  Millman, Jarrod and
                  Lai, Jeff and
                  Renfro, Mandy and
                  Liu, Siqi and
                  Stadler, Jörg and
                  Glatard, Tristan and
                  Kahn, Ari E. and
                  Kong, Xiang-Zhen and
                  Triplett, William and
                  Park, Anne and
                  McDermottroe, Conor and
                  Hallquist, Michael and
                  Poldrack, Russell and
                  Perkins, L. Nathan and
                  Noel, Maxime and
                  Gerhard, Stephan and
                  Salvatore, John and
                  Mertz, Fred and
                  Broderick, William and
                  Inati, Souheil and
                  Hinds, Oliver and
                  Brett, Matthew and
                  Durnez, Joke and
                  Tambini, Arielle and
                  Rothmei, Simon and
                  Andberg, Sami Kristian and
                  Cooper, Gavin and
                  Marina, Ana and
                  Mattfeld, Aaron and
                  Urchs, Sebastian and
                  Sharp, Paul and
                  Matsubara, K and
                  Geisler, Daniel and
                  Cheung, Brian and
                  Floren, Andrew and
                  Nickson, Thomas and
                  Pannetier, Nicolas and
                  Weinstein, Alejandro and
                  Dubois, Mathieu and
                  Arias, Jaime and
                  Tarbert, Claire and
                  Schlamp, Kai and
                  Jordan, Kesshi and
                  Liem, Franz and
                  Saase, Victor and
                  Harms, Robbert and
                  Khanuja, Ranjeet and
                  Podranski, Kornelius and
                  Flandin, Guillaume and
                  Papadopoulos Orfanos, Dimitri and
                  Schwabacher, Isaac and
                  McNamee, Daniel and
                  Falkiewicz, Marcel and
                  Pellman, John and
                  Linkersdörfer, Janosch and
                  Varada, Jan and
                  Pérez-García, Fernando and
                  Davison, Andrew and
                  Shachnev, Dmitry and
                  Ghosh, Satrajit},
	  title        = {nipy/nipype: Release 0.13.1},
	  month        = may,
	  year         = 2017,
	  doi          = {10.5281/zenodo.581704},
	  url          = {https://doi.org/10.5281/zenodo.581704}
      }

If you are a Nipype contributor and your name is not mentioned above please submit
a Pull Request modifying `.zenodo.json` file.

When publishing results obtained using Nipype we strongly encourage citing the above reference to give credit to all
Nipype contributors. However, if for some reason the journal you are publishing with does not allow you do cite software
this way you can use the initial paper published in 2011 (see below).

.. admonition:: Reference

   Gorgolewski K, Burns CD, Madison C, Clark D, Halchenko YO, Waskom ML,
   Ghosh SS. (2011). Nipype: a flexible, lightweight and extensible neuroimaging
   data processing framework in Python. Front. Neuroimform. 5:13.

   `Download Paper`__

   __ paper_

::

    @article { Gorgolewski2011,
	title            = "Nipype: a flexible, lightweight and extensible neuroimaging data processing framework in python.",
	year             = "2011",
	author           = "Krzysztof Gorgolewski and Christopher D Burns and Cindee Madison and Dav Clark and Yaroslav O Halchenko and Michael L Waskom and Satrajit S Ghosh",
	journal          = "Front Neuroinform",
	volume           = "5",
	month            = "08",
	doi              = "10.3389/fninf.2011.00013",
	pubmed           = "21897815",
	url              = "https://doi.org/10.3389/fninf.2011.00013",
	issn             = "1662-5196"}


.. include:: links_names.txt


.. include:: ../THANKS.rst
